#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Book of Hours
###

script_version=20230928.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='book-of-hours'
GAME_NAME='Book of Hours'

ARCHIVE_BASE_2_NAME='book_of_hours_2023_9_b_12_67790.sh'
ARCHIVE_BASE_2_MD5='2875c037ee2ff44b41191471449248a1'
ARCHIVE_BASE_2_SIZE='1930344'
ARCHIVE_BASE_2_VERSION='2023.09.b.12-gog67790'
ARCHIVE_BASE_2_URL='https://www.gog.com/game/book_of_hours_perpetual_edition'

ARCHIVE_BASE_1_NAME='book_of_hours_2023_8_g_2_67165.sh'
ARCHIVE_BASE_1_MD5='4d6c689f68c4debb4ad68a3dc1c018b5'
ARCHIVE_BASE_1_SIZE='1927812'
ARCHIVE_BASE_1_VERSION='2023.08.g.2-gog67165'

ARCHIVE_BASE_0_NAME='book_of_hours_2023_8_a_7_2_66829.sh'
ARCHIVE_BASE_0_MD5='7e8083b57019140127cb7bcffbccb737'
ARCHIVE_BASE_0_SIZE='2900000'
ARCHIVE_BASE_0_VERSION='2023.08.a.7.2-gog66829'

UNITY3D_NAME='bh'

CONTENT_PATH_DEFAULT='data/noarch/game'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libm.so.6
libpthread.so.0
librt.so.1
libz.so.1'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
