#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Dark Reign 2
###

script_version=20231008.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='dark-reign-2'
GAME_NAME='Dark Reign 2'

ARCHIVE_BASE_1_NAME='setup_dark_reign_2_1.3_(56283).exe'
ARCHIVE_BASE_1_MD5='23b441f1a8ffd5302e7cde3c1099cb73'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_VERSION='1.3.882-gog'
ARCHIVE_BASE_1_SIZE='580000'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/dark_reign_2'

ARCHIVE_BASE_0_NAME='setup_dark_reign2_2.0.0.11.exe'
ARCHIVE_BASE_0_MD5='9a3d10825507b73c4db178f9caea2406'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_VERSION='1.3.882-gog2.0.0.11'
ARCHIVE_BASE_0_SIZE='450000'

CONTENT_PATH_DEFAULT='.'
CONTENT_PATH_DEFAULT_0='app'
CONTENT_GAME_BIN_FILES='
library
anet.inf
dxcfg.ini
settings.cfg
*.dll
*.exe'
CONTENT_GAME_DATA_FILES='
missions
mods
music
packs
sides
worlds'
CONTENT_DOC_DATA_FILES='
*.htm
*.pdf
*.rtf
*.txt'

USER_PERSISTENT_DIRECTORIES='
mods
users'
USER_PERSISTENT_FILES='
settings.cfg'

WINE_WINETRICKS_VERBS='win98'

APP_MAIN_EXE='dr2.exe'
APP_MAIN_EXE_0='launcher.exe'
APP_MAIN_ICON='dr2.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"

# Work around prompt for CD-key

## TODO: Fetch the key from a file provided by the archive, instead of hardcoding it here.
registry_dump_cdkey_file='registry-dumps/cdkey.reg'
registry_dump_cdkey_content='Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\Software\WON\CDKeys]
"DarkReign2"=hex:56,c1,0c,ed,bb,61,40,19,99,3d,cd,6c,78,51,4c,5e'
CONTENT_GAME_BIN_FILES="${CONTENT_GAME_BIN_FILES:-}
$registry_dump_cdkey_file"
APP_REGEDIT="${APP_REGEDIT:-} $registry_dump_cdkey_file"
SCRIPT_DEPS="${SCRIPT_DEPS:-} iconv"

## FIXME: This game can get display issues on some resolutions, when run on Wayland without using a virtual desktop.

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Delete unwanted files
	rm --force --recursive \
		'commonappdata' \
		'__redist' \
		'tmp'

	# Work around prompt for CD-key
	mkdir --parents "$(dirname "$registry_dump_cdkey_file")"
	printf '%s' "$registry_dump_cdkey_content" | \
		iconv --from-code=UTF-8 --to-code=UTF-16 --output="$registry_dump_cdkey_file"
)

# Include game data

PKG='PKG_DATA'
icons_inclusion
content_inclusion_default

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
