#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Desperados 3
###

script_version=20230715.2

GAME_ID='desperados-3'
GAME_NAME='Desperados Ⅲ'

ARCHIVE_BASE_0='setup_desperados_3_1.7_(43311).exe'
ARCHIVE_BASE_0_MD5='27d07bcafb7b0a0c5bd0af5a0b91edb8'
ARCHIVE_BASE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent'
ARCHIVE_BASE_0_PART1='setup_desperados_3_1.7_(43311)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='5554579fd67870ad94347b70df2743f6'
ARCHIVE_BASE_0_PART2='setup_desperados_3_1.7_(43311)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='f7f43119dda91362ec45b122e4ea641d'
ARCHIVE_BASE_0_PART3='setup_desperados_3_1.7_(43311)-3.bin'
ARCHIVE_BASE_0_PART3_MD5='51948b7e8d6a9e45638b49988f86c5f9'
ARCHIVE_BASE_0_SIZE='24000000'
ARCHIVE_BASE_0_VERSION='1.5.8-gog43311'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/desperados_iii'

UNITY3D_NAME='Desperados III'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES="
MonoBleedingEdge
${UNITY3D_NAME}_Data/Plugins
${UNITY3D_NAME}.exe
*.dll
THQNOnline
MiVersion
thqnocfg.dat"
CONTENT_GAME_DATA_GI_FILES="
${UNITY3D_NAME}_Data/GI"
CONTENT_GAME_DATA_STREAMINGASSETS_FILES="
${UNITY3D_NAME}_Data/StreamingAssets"
CONTENT_GAME_DATA_LEVELS_1_FILES="
${UNITY3D_NAME}_Data/level?
${UNITY3D_NAME}_Data/level?.resS
${UNITY3D_NAME}_Data/level??
${UNITY3D_NAME}_Data/level??.resS"
CONTENT_GAME_DATA_LEVELS_2_FILES="
${UNITY3D_NAME}_Data/level???
${UNITY3D_NAME}_Data/level???.resS"

WINE_DIRECT3D_RENDERER='dxvk'
WINE_PERSISTENT_DIRECTORIES='
users/${USER}/AppData/Local/Desperados III/user_steam_117093590311632897'

PACKAGES_LIST='PKG_BIN PKG_DATA_GI PKG_DATA_STREAMINGASSETS PKG_DATA_LEVELS_1 PKG_DATA_LEVELS_2 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_GI_ID="${PKG_DATA_ID}-gi"
PKG_DATA_GI_DESCRIPTION="$PKG_DATA_DESCRIPTION - gi"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_GI_ID"

PKG_DATA_STREAMINGASSETS_ID="${PKG_DATA_ID}-streamingassets"
PKG_DATA_STREAMINGASSETS_DESCRIPTION="$PKG_DATA_DESCRIPTION - streamingassets"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_STREAMINGASSETS_ID"

PKG_DATA_LEVELS_ID="${PKG_DATA_ID}-levels"
PKG_DATA_LEVELS_1_ID="${PKG_DATA_LEVELS_ID}-1"
PKG_DATA_LEVELS_2_ID="${PKG_DATA_LEVELS_ID}-2"
PKG_DATA_LEVELS_DESCRIPTION="$PKG_DATA_DESCRIPTION - levels"
PKG_DATA_LEVELS_1_DESCRIPTION="$PKG_DATA_LEVELS_DESCRIPTION - 1"
PKG_DATA_LEVELS_2_DESCRIPTION="$PKG_DATA_LEVELS_DESCRIPTION - 2"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_LEVELS_1_ID $PKG_DATA_LEVELS_2_ID"

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
video/quicktime, variant=(string)iso'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Delete unwanted files
	rm --force --recursive \
		'__redist' \
		'app' \
		'commonappdata' \
		'thqnonline' \
		'tmp'
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
