#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Grim Dawn expansions:
# - Ashes of Malmouth
# - Forgotten Gods
###

script_version=20230928.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='grim-dawn'
GAME_NAME='Grim Dawn'

EXPANSION_ID_ASHES='ashes-of-malmouth'
EXPANSION_NAME_ASHES='Ashes of Malmouth'

EXPANSION_ID_GODS='forgotten-gods'
EXPANSION_NAME_GODS='Forgotten Gods'

# Archives

## Ashes of Malmouth

ARCHIVE_BASE_ASHES_0_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.1.9.8_(65199).exe'
ARCHIVE_BASE_ASHES_0_MD5='0754f567005ecc7d758d905992e5d7f7'
ARCHIVE_BASE_ASHES_0_TYPE='innosetup'
ARCHIVE_BASE_ASHES_0_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.1.9.8_(65199)-1.bin'
ARCHIVE_BASE_ASHES_0_PART1_MD5='49bc0c617d4ab9415298994ba4a085b8'
ARCHIVE_BASE_ASHES_0_SIZE='2506744'
ARCHIVE_BASE_ASHES_0_VERSION='1.1.9.8-gog65199'
ARCHIVE_BASE_ASHES_0_URL='https://www.gog.com/game/grim_dawn_ashes_of_malmouth'

## Forgotten Gods

ARCHIVE_BASE_GODS_0_NAME='setup_grim_dawn_-_forgotten_gods_1.1.9.8_(65199).exe'
ARCHIVE_BASE_GODS_0_MD5='6615eb32a355092c4d0173457f701e31'
ARCHIVE_BASE_GODS_0_TYPE='innosetup'
ARCHIVE_BASE_GODS_0_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.1.9.8_(65199)-1.bin'
ARCHIVE_BASE_GODS_0_PART1_MD5='55ac480dee30aa6cfa6a8b466f521406'
ARCHIVE_BASE_GODS_0_SIZE='3220672'
ARCHIVE_BASE_GODS_0_VERSION='1.1.9.8-gog65199'
ARCHIVE_BASE_GODS_0_URL='https://www.gog.com/game/grim_dawn_forgotten_gods'


CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_MAIN_FILES='
gdx?
survivalmode?'

PKG_MAIN_DEPS="$GAME_ID"
PKG_MAIN_DEPS_GODS="$PKG_MAIN_DEPS ${GAME_ID}-${EXPANSION_ID_ASHES}"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_default

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
